/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef TRANSFERITEMDELEGATE_H
#define TRANSFERITEMDELEGATE_H

#include <QStyledItemDelegate>

class TransferItemDelegate : public QStyledItemDelegate
{
    Q_OBJECT

public:
    explicit TransferItemDelegate(QObject *parent = 0);
    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
#ifndef TABLE_TRANSFER_VIEW
    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
#endif
};

#endif // TRANSFERPROGRESSDELEGATE_H
